Module cli

Module cli 

Command-line parsing for pcf-debug.

Hand-written on top of std::env::args to keep the tool free of any argument-parsing dependency (matching the reference crate’s minimal-deps posture). The grammar is:

pcf-debug <FILE> [subcommand] [flags]

Structs

Args
ByteRange
A byte range for hexdump --range start[:len].
DecodeOpts
HexOpts

Enums

ColorChoice
Whether to colour the output.
Command
Parsed
Outcome of parsing: either runnable args, or a message to print and exit.

Functions

help
The full help text.
parse
Parse arguments (excluding argv[0]).