pub struct Decoded {
pub format_name: String,
pub fields: Vec<FieldNode>,
pub warnings: Vec<String>,
}Expand description
The result of decoding one partition.
Fields
format_name: StringHuman name of the format that was decoded, e.g. "PFS_NODE".
fields: Vec<FieldNode>warnings: Vec<String>Non-fatal spec violations and remarks surfaced to the user.